==> haskell-wreq-0.5.3.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wreq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wreq
version: 0.5.3.1
id: wreq-0.5.3.1-j1Dnuvf1EPBMBoVE4XKxy
key: wreq-0.5.3.1-j1Dnuvf1EPBMBoVE4XKxy
license: BSD-3-Clause
copyright: 2014 Bryan O'\''Sullivan
maintainer: bos@serpentine.com
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/wreq
synopsis: An easy-to-use HTTP client library.
description:
    .
    A web client library that is designed for ease of use.
    .
    Tutorial: <http://www.serpentine.com/wreq/tutorial.html>
    .
    Features include:
    .
    * Simple but powerful `lens`-based API
    .
    * A solid test suite, and built on reliable libraries like
    http-client and lens
    .
    * Session handling includes connection keep-alive and pooling, and
    cookie persistence
    .
    * Automatic response body decompression
    .
    * Powerful multipart form and file upload handling
    .
    * Support for JSON requests and responses, including navigation of
    schema-less responses
    .
    * Basic and OAuth2 bearer authentication
    .
    * Early TLS support via the tls package
category: Web
abi: 8d92c3c7f866065ef22cc47d2c167e79
exposed: True
exposed-modules:
    Network.Wreq Network.Wreq.Cache Network.Wreq.Cache.Store
    Network.Wreq.Lens Network.Wreq.Session Network.Wreq.Types
hidden-modules: Network.Wreq.Internal Network.Wreq.Internal.AWS
                Network.Wreq.Internal.Lens Network.Wreq.Internal.Link
                Network.Wreq.Internal.OAuth1 Network.Wreq.Internal.Types
                Network.Wreq.Lens.Machinery Network.Wreq.Lens.TH Paths_wreq
import-dirs: /usr/lib/ghc-8.6.3/site-local/wreq-0.5.3.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/wreq-0.5.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/wreq-0.5.3.1
hs-libraries: HSwreq-0.5.3.1-j1Dnuvf1EPBMBoVE4XKxy
depends:
    aeson-1.4.2.0-BdBVLho0lrWC4iPoef6lEw
    attoparsec-0.13.2.2-BKfIbjnWW4NITXC0apvm49
    authenticate-oauth-1.6-8i5qogbu401CMhlPSSzIfU base-4.12.0.0
    base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu containers-0.6.0.1
    cryptonite-0.25-5E9EuEAz1M1JrY25iIyNbL
    exceptions-0.10.0-9c5BjQipUdiGeORB8copQH ghc-prim-0.5.3
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    http-client-0.5.14-KmxCAwrvYNOKKldA9lKdu3
    http-client-tls-0.3.5.3-20zBeLE4nhkH5BLQr5N2Re
    http-types-0.12.2-EPHxgevZtaq66NPaeVf0FD
    lens-4.17-FbLYzBYXW5f7bjmi9eGvx2
    lens-aeson-1.0.2-FYzy9XZipJx1V0x2SsaESa
    memory-0.14.18-7DMShoecVUC5dB7z3aQ1xS
    mime-types-0.1.0.8-EyyVHsFtYS19TE9FosmRtL
    psqueues-0.2.7.0-KUVejJ6deoBOKGhMhIlo7 template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2
    time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
    unordered-containers-0.2.9.0-BISrknrydugK8yp2XIgTJd
haddock-interfaces: /usr/share/doc/haskell-wreq/html/wreq.haddock
haddock-html: /usr/share/doc/haskell-wreq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wreq-0.5.3.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wreq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wreq
version: 0.5.3.1
id: wreq-0.5.3.1-HQaKl7PDc6jCvQSmRmIS1i
key: wreq-0.5.3.1-HQaKl7PDc6jCvQSmRmIS1i
license: BSD-3-Clause
copyright: 2014 Bryan O'\''Sullivan
maintainer: bos@serpentine.com
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/wreq
synopsis: An easy-to-use HTTP client library.
description:
    .
    A web client library that is designed for ease of use.
    .
    Tutorial: <http://www.serpentine.com/wreq/tutorial.html>
    .
    Features include:
    .
    * Simple but powerful `lens`-based API
    .
    * A solid test suite, and built on reliable libraries like
    http-client and lens
    .
    * Session handling includes connection keep-alive and pooling, and
    cookie persistence
    .
    * Automatic response body decompression
    .
    * Powerful multipart form and file upload handling
    .
    * Support for JSON requests and responses, including navigation of
    schema-less responses
    .
    * Basic and OAuth2 bearer authentication
    .
    * Early TLS support via the tls package
category: Web
abi: ec27228a2eaec6c10ebf37084d43e72d
exposed: True
exposed-modules:
    Network.Wreq Network.Wreq.Cache Network.Wreq.Cache.Store
    Network.Wreq.Lens Network.Wreq.Session Network.Wreq.Types
hidden-modules: Network.Wreq.Internal Network.Wreq.Internal.AWS
                Network.Wreq.Internal.Lens Network.Wreq.Internal.Link
                Network.Wreq.Internal.OAuth1 Network.Wreq.Internal.Types
                Network.Wreq.Lens.Machinery Network.Wreq.Lens.TH Paths_wreq
import-dirs: /usr/lib/ghc-8.6.3/site-local/wreq-0.5.3.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/wreq-0.5.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/wreq-0.5.3.1
hs-libraries: HSwreq-0.5.3.1-HQaKl7PDc6jCvQSmRmIS1i
depends:
    aeson-1.4.2.0-BdBVLho0lrWC4iPoef6lEw
    attoparsec-0.13.2.2-BKfIbjnWW4NITXC0apvm49
    authenticate-oauth-1.6-BoPZ3QvTzBxJ2D8N2n8CBP base-4.12.0.0
    base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu containers-0.6.0.1
    cryptonite-0.25-5E9EuEAz1M1JrY25iIyNbL
    exceptions-0.10.0-9c5BjQipUdiGeORB8copQH ghc-prim-0.5.3
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    http-client-0.5.14-9KJJRPJSiTV4C954FXQZYp
    http-client-tls-0.3.5.3-BVLsQI6LDpsDSXqlpiL92K
    http-types-0.12.2-EPHxgevZtaq66NPaeVf0FD
    lens-4.17-FbLYzBYXW5f7bjmi9eGvx2
    lens-aeson-1.0.2-FYzy9XZipJx1V0x2SsaESa
    memory-0.14.18-7DMShoecVUC5dB7z3aQ1xS
    mime-types-0.1.0.9-2hmZJ5CmRudCuwA0xwTABk
    psqueues-0.2.7.0-KUVejJ6deoBOKGhMhIlo7 template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2
    time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
    unordered-containers-0.2.9.0-BISrknrydugK8yp2XIgTJd
haddock-interfaces: /usr/share/doc/haskell-wreq/html/wreq.haddock
haddock-html: /usr/share/doc/haskell-wreq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
